==> nik-supernav-1.1.1.tgz: package/src/components/navbar/PrimaryNavLinks/MegaMenus/MegaMenuStyles.js <==
// Styles here will override Bulma styles
import styled, { css } from "styled-components";
import media, { setBreakPoints } from 'css-in-js-media';
import { Row, Col } from "../../../_atoms/grid";
import Element from "../../../element";

setBreakPoints({ desktop: 1024, largeDesktop: 1710, tablet: 840 });

// SOLUTIONS MEGA MENU

export const SolutionsMegaMenuContainer = styled.div`
  max-height: 400px;
  width: 900px;
  display: flex;
  flex-direction: column;
  flex-wrap: wrap;
  margin-bottom: 52px;

  .chevron {
    display: none !important;
  }

  ${media('<largeDesktop')} {
    max-height: 400px;
    margin: 0 auto;
  }
  ${media('<desktop')} {
    width: auto;
    margin: 0 auto;
  }

  ${media('<tablet')} {
    max-height: 1000px;
    margin: 24px auto;
  }
`;

// PRODUCTS MEGA MENU

export const SmallIconContainer = styled.div`
  margin-left: 10px;
  display: flex;
  flex-direction: column;

  ${media('<tablet')} {
    margin-bottom: 20px;
  }
`;

export const SmallIconImg = styled.div`
  margin-top: 40px;
  width: 30px;

  ${media('<desktop')} {
    margin-right: 5px;
    margin-top: -5px;
  }
`;

export const SmallIconHeadlineContainer = styled.div`
  display: flex;
  margin-top: 10px;

  > h1.is-6 {
    color: #031b4e !important;
    margin-bottom: 19px !important;
  }

  ${media('<desktop')} {
    margin-bottom: 5px;
  }
`;

export const SmallIconLink = styled(Element)`
  color: hsl(221, 19%, 44%);
  font-size: 14px !important;
  font-family: 'Inter-Regular', 'Helvetica', 'san-serif' !important;
  margin-bottom: 12px;
  padding-bottom: 0 !important;

  &:hover {
    color: #0069ff;
  }

`;

export const MegaMenuLargeIconLinkContainer = styled(Element)`
  margin-top: 23px;
  .chevron {
    display: none;
    margin-left: 24px;
  }
  &:hover {
    color: #0069ff;
    .chevron {
      display: block;
    }
  }

  a {
    padding: .375rem 1rem;
  }
  ${media('<desktop')} {
    margin-left: 0px;
  }
`;

export const LargeIconLinksStyledContainter = styled.div`
  width: 229px;
  height: 328px;
`

// COMMUNITY MEGA MENU

export const MegaMenuListLink = styled(Element)`
  color: hsl(221, 19%, 44%) !important;
  font-family: 'Inter-Regular', 'Helvetica', 'sans-serif';
  font-size: 14px !important;
  line-height: 1.2;
  padding: 8px 0 8px 50px !important;

  &:hover {
    color: #0069ff !important;
  }

  ${media('<desktop')} {
    font-size: 14px !important;
    margin-bottom: 10px;
    margin-left: 15px;
    margin-right: 15px;
    padding: 5px 0 15px 0;
    width: 100%;
  }
`;

export const MegaMenuArticleContainer = styled(Element)`
  display: flex;
  margin: 20px 0 20px 50px !important;
  padding: 0 !important;
  white-space: normal !important;
  cursor: pointer;

  :first-of-type {
    margin-top: 30px !important;
  }

  :hover p {
    color: #0069ff !important;
  }

  ${media('<desktop')} {
    align-items: center;
    display: flex;

    margin-top: 0 !important;

    :first-of-type {
      margin-top: 0 !important;
    }
  }
`;

export const MegaMenuArticleText = styled.p`
  color: #5b6987 !important;
  font-family: 'Inter-Regular', 'Helvetica', 'sans-serif';
  line-height: 1.5;
  max-width: 300px;
  padding-left: 20px;
  font-size: 14px;

  ${media('<desktop')} {
    font-size: 13px !important;
    line-height: 1.5em !important;
    max-width: 170px;
    padding-left: 10px;
  }
`;

export const MegaMenuArticleImg = styled.img`
  max-width: 40px;
  max-height: 40px;

  ${media('<desktop')} {
    min-width: 50px;
    min-height: 50px;
  }
`;

// SOLUTIONS MEGA MENU, PRODUCTS MEGA MENU, & COMMUNITY MEGA MENU

export const MegaMenuColumns = styled(Row)`
  flex-direction: ${props => props.flexDirection ? props.flexDirection : 'row'};
  padding: ${props => props.padding ? props.padding : 'auto'};
  flex-wrap: nowrap !important;
  min-height: 460px;
  border-bottom: 1px solid #F1F7FF;

  > div {

  }

  ${media('<desktop')} {
    display: flex;
    flex-direction: column;
    justify-content: center;
    min-width: none;
    min-height: none;
    border-bottom: none;

    a.nav-item {
      padding: .375rem 1rem;
      padding: 0 20px 20px 0;
    }
  }
`;

export const MegaMenuBorderRight = styled.div`
  padding: 24px !important;
  min-width: 380px;

  background: #F1F7FF;
  border-radius: 8px 0px 0px 0px;

  ${media('<desktop')} {
    background: #fff;
    min-width: auto;
    min-height: auto;
  }
`;

export const NavTitle = styled.h1`
  color: #0069FF;
  font-family: 'Inter-Bold', 'Helvetica', 'san-serif';
  font-size: 11px !important;
  font-weight: bold;
  letter-spacing: 1px !important;
  margin-bottom: 20px !important;
  margin-top: 40px;
  text-transform: uppercase;

  &.products-title,
  &.solutions-title,
  &.community-title {
    padding: .375rem 1rem;
  }

  &.products-title,
  &.solutions-title,
  &.community-title {
    margin-top: 20px !important;
  }

  &.solutions-title {
    margin-bottom: 8px !important;
  }

  &.community-get-involved-title,
  &.community-featured-title {
    color: #031b4e;
    padding: 8px 0 8px 50px !important;
  }

  ${media('<desktop')} {
    margin-bottom: 5px;
    margin-top: 0;
    padding-left: 0px !important;
  }

  ${media('<tablet')} {
    margin-bottom: 5px !important;
  }
`;

export const LargeIconLink = styled(Element)`
  display: flex;

  &:hover {
    background: rgba(0, 105, 255, 0.08) !important;

    &:after {
      content: url("../../../../assets/images/chevron-icon.svg");
      display: block;
    }

    h1 {
      color: #0069ff !important;
    }
  }


  div:hover {
    h1,
    span {
      color: #0069ff !important;
    }
  }
`;

export const LargeIconImg = css`
  height: 40px;
  margin-top: 2px;
  max-height: 40px !important;
  max-width: 40px;
`;

export const LargeIconTitle = styled.h1`
  color: #031b4e !important;
  font-family: 'Inter-Regular', 'Helvetica', 'sans-serif' !important;
  font-size: 16px !important;
  font-weight: bold;
  letter-spacing: 0 !important;
  margin-top: 2px;
  margin-bottom: 2px !important;

  ${media('<desktop')} {
    font-size: 14px !important;
    margin-left: 5px;
  }
`;

export const LargeIconSubtitle = styled.div`
  color: hsl(221, 19%, 44%) !important;
  font-size: 16px !important;
  font-family: 'Inter-Regular', 'Helvetica', 'san-serif' !important;

  ${media('<desktop')} {
    font-size: 12px !important;
    margin-left: 5px;
  }
`;

export const MegaMenuHr = styled.hr`
  background-color: hsl(218, 18%, 91%);
  display: none;
  margin-top: 20px;
  width: 100%;
`;

export const MegaMenuDropdown = styled.div`
  left: 240px;
  box-shadow: 0 2px 4px rgba(3, 27, 78, 0.1);
  padding-bottom: 0.8rem;
  padding-top: 0;
  margin-top: -1px;
  position: absolute;
  top: 64px;
  display: flex;
  flex-direction: column;
  align-items: center;
  border-bottom: 1px solid #F1F7FF;
  border-top: 2px solid #dbdbdb;
  background: white;

  justify-self: center;
  margin-left: auto;
  margin-right: auto;

  &#communityMegaDropdown {
    padding-bottom: 0px !important;
  }

  .get-involved, featured {
    color: #031b4e;
    display: flex;
    flex-direction: column;
  }

  ${media('<largeDesktop')} {
    left: 65px;
  }

  ${media('<desktop')} {
    max-width: 80%;
    overflow: hidden;
    margin: 0;
    box-shadow: none;
    display: block;
    position: relative;
    flex-direction: column;
    left: 0;
    margin-bottom: 100px;
    border-bottom: none;
    border-top: none;
  }
`;

export const MegaMenuAllLink = styled.div`
  padding-top: 20px;
  padding-bottom: 4px;
  text-align: center;
  width: 100%;

  ${media('<desktop')} {
  }
`;

export const MegaMenuAllLinkA = styled(Element)`
  color: hsl(215, 100%, 50%) !important;
  font-family: 'Inter-Regular', 'Helvetica', 'san-serif' !important;
  font-size: 14px !important;
  text-align: center;
`;

export const MegaMenuArrow = styled.img`
  color: hsl(218, 18%, 91%) !important;
  margin-bottom: -3px;
  max-height: 15px !important;
  max-width: 15px;
`;

export const MegaMenuColumn = styled(Col)`
  margin-right: 28px;
  padding: 0px;
  padding-left: 15px;
  display: flex;
  flex-direction: column;
  flex: ${props => props.size ? props.size : 'auto'};

  :nth-of-type(4n),
  :nth-of-type(5n) {
  margin-top: -80px;
  }

  :nth-of-type(5n) {
    margin-left: -220px;
  }

  ${media('<desktop')} {
    margin-right: 0;

    :nth-of-type(4n),
    :nth-of-type(5n) {
      margin-top: 20px
    }
  }

  ${media('<desktop')} {
    margin-right: 0;

    :nth-of-type(4n),
    :nth-of-type(5n) {
      margin-left: 0;
    }
  }
`;

==> nik-supernav-1.2.0.tgz: package/src/components/navbar/PrimaryNavLinks/MegaMenus/MegaMenuStyles.js <==
// Styles here will override Bulma styles
import styled, { css } from "styled-components";
import media, { setBreakPoints } from 'css-in-js-media';
import { Row, Col } from "../../../_atoms/grid";
import Element from "../../../element";

setBreakPoints({ desktop: 1024, largeDesktop: 1710, tablet: 840 });

// SOLUTIONS MEGA MENU

export const SolutionsMegaMenuContainer = styled.div`
  height: 480px;
  width: 900px;
  display: flex;
  flex-direction: column;
  flex-wrap: wrap;
  margin-bottom: -40px;

  .chevron {
    display: none !important;
  }

  ${media('<largeDesktop')} {
    max-height: 480px;
    margin: 0 auto;
  }
  ${media('<desktop')} {
    width: auto;
    margin: 0 auto;
  }

  ${media('<tablet')} {
    max-height: 1000px;
    margin: 24px auto;
  }
`;

// PRODUCTS MEGA MENU

export const SmallIconContainer = styled.div`
  margin-left: 10px;
  display: flex;
  flex-direction: column;

  ${media('<tablet')} {
    margin-bottom: 20px;
  }
`;

export const SmallIconImg = styled.div`
  margin-top: 40px;
  width: 30px;

  ${media('<desktop')} {
    margin-right: 5px;
    margin-top: -5px;
  }
`;

export const SmallIconHeadlineContainer = styled.div`
  display: flex;
  margin-top: 10px;

  > h1.is-6 {
    color: #031b4e !important;
    margin-bottom: 19px !important;
  }

  ${media('<desktop')} {
    margin-bottom: 5px;
  }
`;

export const SmallIconLink = styled(Element)`
  color: hsl(221, 19%, 44%);
  font-size: 14px !important;
  font-family: 'Inter-Regular', 'Helvetica', 'san-serif' !important;
  margin-bottom: 12px;
  padding-bottom: 0 !important;

  &:hover {
    color: #0069ff;
  }

`;

export const MegaMenuLargeIconLinkContainer = styled(Element)`
  margin-top: 23px;
  display: flex;
  position: relative;

  .chevron {
    position: absolute;
    display: none;
  }
  &:hover {
    color: #0069ff;
    .chevron {
      display: block;
      right: 10px;
      top: 22px;
    }
  }

  a {
    display: flex;
    justify-content: space-between;
    width: 100%;
    padding: .8rem 1rem;
  }
  ${media('<desktop')} {
    margin-left: 0px;
  }
`;

export const LargeIconLinksStyledContainter = styled.div`
  width: 229px;
  height: 328px;
`

// COMMUNITY MEGA MENU

export const MegaMenuListLink = styled(Element)`
  color: hsl(221, 19%, 44%) !important;
  font-family: 'Inter-Regular', 'Helvetica', 'sans-serif';
  font-size: 14px !important;
  line-height: 1.2;
  padding: 8px 0 8px 50px !important;

  &:hover {
    color: #0069ff !important;
  }

  ${media('<desktop')} {
    font-size: 14px !important;
    margin-bottom: 10px;
    margin-left: 15px;
    margin-right: 15px;
    padding: 5px 0 15px 0;
    width: 100%;
  }
`;

export const MegaMenuArticleContainer = styled(Element)`
  display: flex;
  margin: 20px 0 20px 50px !important;
  padding: 0 !important;
  white-space: normal !important;
  cursor: pointer;

  :first-of-type {
    margin-top: 30px !important;
  }

  :hover p {
    color: #0069ff !important;
  }

  ${media('<desktop')} {
    align-items: center;
    display: flex;

    margin-top: 0 !important;

    :first-of-type {
      margin-top: 0 !important;
    }
  }
`;

export const MegaMenuArticleText = styled.p`
  color: #5b6987 !important;
  font-family: 'Inter-Regular', 'Helvetica', 'sans-serif';
  line-height: 1.5;
  max-width: 300px;
  padding-left: 20px;
  font-size: 14px;

  ${media('<desktop')} {
    font-size: 13px !important;
    line-height: 1.5em !important;
    max-width: 170px;
    padding-left: 10px;
  }
`;

export const MegaMenuArticleImg = styled.img`
  max-width: 40px;
  max-height: 40px;

  ${media('<desktop')} {
    min-width: 50px;
    min-height: 50px;
  }
`;

// SOLUTIONS MEGA MENU, PRODUCTS MEGA MENU, & COMMUNITY MEGA MENU

export const MegaMenuColumns = styled(Row)`
  flex-direction: ${props => props.flexDirection ? props.flexDirection : 'row'};
  padding: ${props => props.padding ? props.padding : 'auto'};
  flex-wrap: nowrap !important;
  min-height: 460px;
  border-bottom: 1px solid #F1F7FF;

  > div {

  }

  ${media('<desktop')} {
    display: flex;
    flex-direction: column;
    justify-content: center;
    min-width: none;
    min-height: none;
    border-bottom: none;

    a.nav-item {
      padding: .375rem 1rem;
      padding: 0 20px 20px 0;
    }
  }
`;

export const MegaMenuBorderRight = styled.div`
  padding: 24px !important;
  min-width: 380px;

  background: #F1F7FF;
  border-radius: 8px 0px 0px 0px;

  ${media('<desktop')} {
    background: #fff;
    min-width: auto;
    min-height: auto;
  }
`;

export const NavTitle = styled.h1`
  color: #0069FF;
  font-family: 'Inter-Bold', 'Helvetica', 'san-serif';
  font-size: 11px !important;
  font-weight: bold;
  letter-spacing: 1px !important;
  margin-bottom: 20px !important;
  margin-top: 40px;
  text-transform: uppercase;

  &.products-title,
  &.solutions-title,
  &.community-title {
    padding: .375rem 1rem;
  }

  &.products-title,
  &.solutions-title,
  &.community-title {
    margin-top: 20px !important;
  }

  &.solutions-title {
    margin-bottom: 8px !important;
  }

  &.community-get-involved-title,
  &.community-featured-title {
    color: #031b4e;
    padding: 8px 0 8px 50px !important;
  }

  ${media('<desktop')} {
    margin-bottom: 5px;
    margin-top: 0;
    padding-left: 0px !important;
  }

  ${media('<tablet')} {
    margin-bottom: 5px !important;
  }
`;

export const LargeIconLink = styled(Element)`
  display: flex;

  &:hover {
    background: rgba(0, 105, 255, 0.08) !important;

    &:after {
      content: url("../../../../assets/images/chevron-icon.svg");
      display: block;
    }

    h1 {
      color: #0069ff !important;
    }
  }


  div:hover {
    h1,
    span {
      color: #0069ff !important;
    }
  }
`;

export const LargeIconImg = css`
  height: 40px;
  margin-top: 2px;
  max-height: 40px !important;
  max-width: 40px;
`;

export const LargeIconTitle = styled.h1`
  color: #031b4e !important;
  font-family: 'Inter-Regular', 'Helvetica', 'sans-serif' !important;
  font-size: 16px !important;
  font-weight: bold;
  letter-spacing: 0 !important;
  margin-top: 2px;
  margin-bottom: 2px !important;

  ${media('<desktop')} {
    font-size: 14px !important;
    margin-left: 5px;
  }
`;

export const LargeIconSubtitle = styled.div`
  color: hsl(221, 19%, 44%) !important;
  font-size: 16px !important;
  font-family: 'Inter-Regular', 'Helvetica', 'san-serif' !important;

  ${media('<desktop')} {
    font-size: 12px !important;
    margin-left: 5px;
  }
`;

export const MegaMenuHr = styled.hr`
  background-color: hsl(218, 18%, 91%);
  display: none;
  margin-top: 20px;
  width: 100%;
`;

export const MegaMenuDropdown = styled.div`
  left: 240px;
  margin-top: -2.8px;
  border-top: 1px solid rgb(229,232,237);
  box-shadow: 0 2px 4px rgba(3, 27, 78, 0.1);
  padding-bottom: 0.8rem;
  padding-top: 0;
  margin-top: -1px;
  position: absolute;
  top: 65px;
  display: flex;
  flex-direction: column;
  align-items: center;
  border-bottom: 1px solid #F1F7FF;
  background: white;
  z-index: 4;

  justify-self: center;
  margin-left: auto;
  margin-right: auto;

  &#communityMegaDropdown {
    padding-bottom: 0px !important;
  }

  .get-involved, featured {
    color: #031b4e;
    display: flex;
    flex-direction: column;
  }

  ${media('<largeDesktop')} {
    left: 65px;
  }

  ${media('<desktop')} {
    max-width: 80%;
    overflow: hidden;
    margin: 0;
    box-shadow: none;
    display: block;
    position: relative;
    flex-direction: column;
    left: 0;
    margin-bottom: 100px;
    border-bottom: none;
    border-top: none;
  }
`;

export const MegaMenuAllLink = styled.div`
  padding-top: 20px;
  padding-bottom: 4px;
  text-align: center;
  width: 100%;

  ${media('<desktop')} {
  }
`;

export const MegaMenuAllLinkA = styled(Element)`

  img {
    color: #031B4E !important;
  }
  color: #031B4E;
  font-family: 'Inter-Regular', 'Helvetica', 'san-serif' !important;
  font-size: 14px !important;
  text-align: center;

  :hover {
    color: hsl(215, 100%, 50%) !important;
  }
`;

export const MegaMenuArrow = styled.img`
  color: hsl(218, 18%, 91%) !important;
  margin-bottom: -3px;
  max-height: 15px !important;
  max-width: 15px;
`;

export const MegaMenuColumn = styled(Col)`
  margin-right: 28px;
  padding: 0px;
  padding-left: 15px;
  display: flex;
  flex-direction: column;
  flex: ${props => props.size ? props.size : 'auto'};

  :nth-of-type(4n),
  :nth-of-type(5n) {
  margin-top: -80px;
  }

  :nth-of-type(5n) {
    margin-left: -220px;
  }

  ${media('<desktop')} {
    margin-right: 0;

    :nth-of-type(4n),
    :nth-of-type(5n) {
      margin-top: 20px
    }
  }

  ${media('<desktop')} {
    margin-right: 0;

    :nth-of-type(4n),
    :nth-of-type(5n) {
      margin-left: 0;
    }
  }
`;
